@@ -3,7 +3,7 @@ package IO::Socket::Socks::Wrapped;
 use IO::Socket;
 use IO::Socket::Socks::Wrapper;
 
-our $VERSION = '0.11_4';
+our $VERSION = '0.08';
 our $AUTOLOAD;
 
 sub new {
@@ -14,10 +14,8 @@ sub new {
 sub AUTOLOAD {
 	my $self = shift;
 	
-	IO::Socket::Socks::Wrapper::_io_socket_connect_ref();
-	
 	local *IO::Socket::connect = sub {
-		return IO::Socket::Socks::Wrapper::_connect(@_, $self->{cfg}, 1);
+		return IO::Socket::Socks::Wrapper::_connect(@_, $self->{cfg});
 	};
 	
 	$AUTOLOAD =~ s/^.+:://;
